@@ -433,7 +433,7 @@ if __name__ == "__main__":
 
     magnet_name = 'MQY_2in1'  #'MQXF_V2'  # 'MBX'  #
     current_path = Path(__file__).parent
-    path = Path.joinpath(current_path.parent.parent, 'tests', 'builders', 'input', magnet_name)
+    path = Path.joinpath(current_path.parent.parent, 'tests', 'builders', 'model_library','magnets', magnet_name, 'input')
     file_model_data = Path.joinpath(path, 'modelData_' + magnet_name + '.yaml')
     if Path.exists(file_model_data):
         with open(file_model_data, "r") as stream:
