@@ -122,7 +122,7 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
         'Circuit.R_parallel': '',
 
         'Power_Supply.I_initial': 'I00',
-        'Power_Supply.t_off:': 't_PC',
+        'Power_Supply.t_off': 't_PC',
         'Power_Supply.t_control_LUT': 't_PC_LUT',
         'Power_Supply.I_control_LUT': 'I_PC_LUT',
         'Power_Supply.R_crowbar': 'R_crowbar',
