@@ -9,14 +9,14 @@ class GatewaySIGMA:
     def __init__(self):
         jars_path = os.path.join(Path(__file__).parent, 'jars', '*')
         #print(f"OS environ paths: {os.environ}")
-        print(jars_path)
-        print(type(jars_path))
-        # print(os.listdir(Path(jars_path).resolve()))
-
+        # print(jars_path)
+        # print(type(jars_path))
+        # # print(os.listdir(Path(jars_path).resolve()))
+        #
         jars_path = os.path.join('steam_sdk', 'wrappers', 'java', 'SIGMA', 'jars', '*')
-        print(jars_path)
-        print(Path(jars_path).resolve())
-        print(type(jars_path))
+        # print(jars_path)
+        # print(Path(jars_path).resolve())
+        # print(type(jars_path))
         # print(os.listdir(Path(jars_path).parent.resolve()))
 
         self.port = launch_gateway(classpath=jars_path, die_on_exit=True)
